<?php

namespace Shopping\Location\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Shopping\Location\Interfaces\LocationRepositoryInterface;

class LocationPublicController extends BaseController
{
    // use LocationWorkflow;

    /**
     * Constructor.
     *
     * @param type \Shopping\Location\Interfaces\LocationRepositoryInterface $location
     *
     * @return type
     */
    public function __construct(LocationRepositoryInterface $location)
    {
        $this->repository = $location;
        parent::__construct();
    }

    /**
     * Show location's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $locations = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$location::$location.names'))
            ->view('$location::public.location.index')
            ->data(compact('$locations'))
            ->output();
    }

    /**
     * Show location's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $locations = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$location::$location.names'))
            ->view('$location::public.location.index')
            ->data(compact('$locations'))
            ->output();
    }

    /**
     * Show location.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $location = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$location->name . trans('$location::$location.name'))
            ->view('$location::public.location.show')
            ->data(compact('$location'))
            ->output();
    }

}
